% Distribution of seismic potency as a funcltion of depth for several M7 strike-slip earthquakes
%
% References:
% 
% Fialko et al., Three-dimensional deformation caused by the Bam, Iran, earthquake and the origin of shallow slip deficit, Nature, 435, doi:10.1038/nature03425, 295-299, 2005.
%
% Jin, Z. and Y. Fialko, Finite slip models of the 2019 Ridgecrest earthquake sequence constrained by space geodetic data and aftershock locations, Bull. Seismol. Soc. Am., doi:10.1785/0120200060, 2020
%
%
% LOAD INPUTS
clear all
close all

orange=[0.5 0.5 0];
pr=1;
Fs=14;
figure(1);
clf
%    'PaperPosition',[1 3 6 6],...
%set('Name','Slip vs Depth',...
%    'PaperPosition',[0.3 2 6 6],...
%    'Position',[10 20 400 400],'number','off');
%    'Color','none',...

subplot(1,1,1)

load LAN_slip.dat;
slip_z=LAN_slip;
ms=max(abs(slip_z(:,1)));
line(slip_z(:,1)/ms,-slip_z(:,2),'LineStyle',':','LineWidth',2,'Color','r','Marker','o','MarkerSize',8,'MarkerEdgeColor','r','MarkerFaceColor','r');

load HM_slip.dat;
slip_z=HM_slip;
ms=max(abs(slip_z(:,1)));
line(slip_z(:,1)/ms,-slip_z(:,2),'LineStyle',':','LineWidth',2,'Color','b','Marker','s','MarkerSize',8,'MarkerEdgeColor','b','MarkerFaceColor','b');

load Izmit_slip.dat;
slip_z=Izmit_slip;
ms=max(abs(slip_z(:,1)));
line(slip_z(:,1)/ms,slip_z(:,2),'LineStyle',':','LineWidth',2,'Color','g','Marker','^','MarkerSize',8,'MarkerEdgeColor','g','MarkerFaceColor','g');

load Bam_slip.dat;
slip_z=Bam_slip;
ms=max(abs(slip_z(:,1)));
line(slip_z(:,1)/ms,-slip_z(:,2),'LineStyle',':','LineWidth',2,'Color',orange,'Marker','d','MarkerSize',8,'MarkerEdgeColor',orange,'MarkerFaceColor',orange);

load EMC_slip.dat;
slip_z=EMC_slip;
ms=max(abs(slip_z(:,1)));
line(slip_z(:,1)/ms,-slip_z(:,2),'LineStyle',':','LineWidth',2,'Color','m','Marker','p','MarkerSize',8,'MarkerEdgeColor','m','MarkerFaceColor','m');

load RC_slip.dat;
slip_z=RC_slip;
ms=max(abs(slip_z(:,2)));
line(slip_z(:,2)/ms,slip_z(:,1),'LineStyle','-','LineWidth',2,'Color','k','Marker','o','MarkerSize',8,'MarkerEdgeColor','k','MarkerFaceColor','k');

xlabel('Normalized slip','FontSize',Fs);
ylabel('Depth, km','FontSize',Fs);
grid on
lb=legend('M_w7.3 Landers','M_w7.1 Hector Mine','M_w7.6 Izmit','M_w6.5 Bam','M_w7.2 EMC','M_w7.1 Ridgecrest','Location','West');
set(lb,'Visible','on','FontSize',Fs);
legend boxoff;

xlim=get(gca,'XLim');
ylim=get(gca,'YLim');
ylim=[0 15];
set(gca,'XLim',xlim,...
         'YLim',ylim,...
         'YDir','reverse',...
         'FontSize',Fs,...
	 'box','on',...
         'XColor','k','YColor','k');
hold off
%wysiwyg

if pr==1
 ppath='./';
% print(gcf, '-djpeg90', '-r300', [ppath 'slip_dept2'])
% print(gcf, '-depsc2', '-r300', [ppath 'slip_depth'])
 print(gcf, '-dpng', '-r300', [ppath 'slip_depth'])
end
